const express = require("express")
const bodyParser = require("body-parser")
const cookieParser = require("cookie-parser")
const { engine: handlebars } = require("express-handlebars")
const sqlite3 = require("sqlite3")

const app = express()
app.use(bodyParser.urlencoded({ extended: false }))
app.use(bodyParser.json())
app.use(cookieParser())
app.use(express.static("static"))
app.engine("html", handlebars({ extname: ".html" }))
app.set("view engine", "html")
app.set("views", "./views")

const db = new sqlite3.Database("jizdnirady.db");

app.get("/", (req, res) => {
    res.render("index", { layout: false, name: "Hledání" });
});

app.post("/", (req, res) => {
    const query = `select times.departure, route.short_name, trip.headsign from times
    join trip on trip.id = times.trip_id
    join route on route.id = trip.route_id
    where times.stop_id in (select id from stop where name = 'Vozovna Žižkov')
    and service_id in (select id from service where monday = 1)
    and times.arrival  > time('now', 'localtime')
    order by times.departure`
    db.all(query, [], (err, result) => {
        res.render("index", { layout: false, name: "Vozovna Žižkov", rows: result });
    });
});

const port = process.env.PORT || 3000
app.listen(port)
console.log(`Server running on http://localhost:${port}`)

